@@ -143,12 +143,52 @@ def assert_editor(screen):
             assert source_line.strip() in screen_line.strip()
 
 
-def assert_export(screen):
+def assert_export(screen, contents):
     """Asserts the export prompt."""
-    assert screen.display[-1].strip() == ":export"
+    assert screen.display[-1].strip() == contents
     # actual command execution is tested by the test_commands.test_export unittest
 
 
+def assert_search_view(screen, label, search, selected):
+    """Asserts the search screen contents."""
+    term_width = len(screen.buffer[0])
+    if selected:
+        assert [c.bg for c in screen.buffer[1].values()] == \
+            ['magenta'] * len(label) + \
+            ['default'] * (term_width - len(label))
+    else:
+        assert [c.fg for c in screen.buffer[1].values()] == \
+            ['blue'] * len(label) + \
+            ['default'] * (term_width - len(label))
+    offset = screen.display[2].index(search)
+    assert [c.fg for c in screen.buffer[2].values()] == \
+        ['default'] * offset + \
+        ['red'] * len(search) + \
+        ['default'] * (term_width - len(search) - offset)
+
+
+def assert_select_list_view(screen, current, selected, labels):
+    """Asserts the selection in the list view of the TUI."""
+    term_width = len(screen.buffer[0])
+    for sel, lab in zip(selected, labels):
+        assert [c.bg for c in screen.buffer[sel].values()] == ['magenta'] * len(lab) + \
+                ['cyan' if sel == current else 'default'] * (term_width - len(lab))
+
+
+def assert_select_show_view(screen, current):
+    """Asserts the selection in the show view."""
+    label_len = len('dummy_entry_for_scroll_testing')
+    with open('./test/dummy_scrolling_entry.bib', 'r') as source:
+        for idx, (screen_line, source_line) in enumerate(zip(screen.display[1:5],
+                                                             source.readlines())):
+            if idx == 0:
+                assert [c.bg for c in screen.buffer[1].values()] == \
+                    ['cyan' if current else 'default'] * 6 + \
+                    ['magenta'] * label_len + \
+                    ['cyan' if current else 'default'] * (len(screen.buffer[0]) - label_len - 6)
+            assert screen_line.strip() in source_line.strip()
+
+
 @pytest.mark.parametrize(['keys', 'assertion', 'assertion_kwargs'], [
         ['', assert_list_view, {
             'current': 1, 'expected': [
@@ -162,7 +202,8 @@ def assert_export(screen):
         ['a-b ./test/example_entry.bib\n', assert_add, {}],
         ['d', assert_delete, {}],
         ['Ge', assert_editor, {}],
-        ['x', assert_export, {}],
+        ['x', assert_export, {'contents': ":export"}],
+        ['x' + 100 * 'j', assert_export, {'contents': 'j' * 79}],  # regression-test on #48
         ['f++ID einstein\n', assert_list_view, {
             'current': 1, 'expected': ['einstein']}],
         ['f--ID einstein\n', assert_list_view, {
@@ -177,12 +218,38 @@ def assert_export(screen):
             'current': 1, 'expected': [
                 'latexcompanion', 'knuthwebsite', 'einstein', 'dummy_entry_for_scroll_testing'
             ]}],
-        pytest.param(
-            'o', lambda _: None, {},
-            marks=[pytest.mark.skip("There is currently no meaningful way of testing this.")]
-        ),
-        ['/', lambda _: None, {}],  # TODO unittest Search command
-        ['v', lambda _: None, {}],  # TODO unittest Select command
+        ['/einstein\njj', assert_search_view, {
+            'label': 'einstein',
+            'search': 'einstein',
+            'selected': False
+        }],
+        ['/einstein\njjv', assert_search_view, {
+            'label': 'einstein',
+            'search': 'einstein',
+            'selected': True
+        }],
+        ['Gv/einstein\njj', assert_search_view, {
+            'label': 'einstein',
+            'search': 'einstein',
+            'selected': True
+        }],
+        ['/einstein\nvq', assert_select_list_view, {'current': 1, 'selected': [4],
+                                                    'labels': ['einstein']}],
+        ['v', assert_select_list_view, {'current': 1, 'selected': [1],
+                                        'labels': ['dummy_entry_for_scroll_testing']}],
+        ['vj', assert_select_list_view, {'current': 2, 'selected': [1],
+                                         'labels': ['dummy_entry_for_scroll_testing']}],
+        ['jvjv', assert_select_list_view, {'current': 3, 'selected': [2, 3],
+                                           'labels': ['knuthwebsite', 'latexcompanion']}],
+        ['vv', assert_list_view, {  # assert that re-selection toggles
+            'current': 1, 'expected': [
+                'dummy_entry_for_scroll_testing', 'knuthwebsite', 'latexcompanion', 'einstein'
+            ]}],
+        ['v\n', assert_select_show_view, {'current': True}],
+        ['\nv', assert_select_show_view, {'current': True}],
+        ['\nvj', assert_select_show_view, {'current': False}],
+        ['\nvq', assert_select_list_view, {'current': 1, 'selected': [1],
+                                           'labels': ['dummy_entry_for_scroll_testing']}],
     ])
 def test_tui(setup, keys, assertion, assertion_kwargs):
     """Test TUI.
@@ -246,7 +313,6 @@ def test_tui_config_color():
     root = os.path.abspath(os.path.dirname(__file__))
     CONFIG.set_config(Path(root + '/../cobib/docs/debug.ini'))
     # overwrite color configuration
-    CONFIG.config['COLORS'] = {}
     CONFIG.config['COLORS']['top_statusbar_bg'] = 'red'
     CONFIG.config['COLORS']['top_statusbar_fg'] = 'blue'
     CONFIG.config['COLORS']['bottom_statusbar_bg'] = 'green'
@@ -268,7 +334,6 @@ def test_tui_config_keys(command, key):
     root = os.path.abspath(os.path.dirname(__file__))
     CONFIG.set_config(Path(root + '/../cobib/docs/debug.ini'))
     # overwrite key binding configuration
-    CONFIG.config['KEY_BINDINGS'] = {}
     CONFIG.config['KEY_BINDINGS'][command] = key
     # NOTE: normally you would never trigger an Add command before reading the database but in this
     # controlled testing scenario we can be certain that this is fine
@@ -301,13 +366,36 @@ def test_tui_quit_prompt(setting, keys):
     root = os.path.abspath(os.path.dirname(__file__))
     CONFIG.set_config(Path(root + '/../cobib/docs/debug.ini'))
     # set prompt_before_quit setting
-    if 'TUI' not in CONFIG.config.keys():
-        CONFIG.config['TUI'] = {}
     CONFIG.config['TUI']['prompt_before_quit'] = setting
     read_database()
     test_tui(None, keys, assert_quit, {'prompt': setting})
 
 
+def assert_open(screen):
+    """Asserts the open menu."""
+    assert '1: [file] /tmp/a.txt' in screen.display[16]
+    assert '2: [file] /tmp/b.txt' in screen.display[17]
+    assert '3: [url] https://www.duckduckgo.com' in screen.display[18]
+    assert '4: [url] https://www.google.com' in screen.display[19]
+    assert "Entry to open [Type 'help' for more info]:" in screen.display[20]
+
+
+def test_tui_open_menu():
+    """Test the open prompt menu for multiple associated files."""
+    # ensure configuration is empty
+    CONFIG.config = {}
+    root = os.path.abspath(os.path.dirname(__file__))
+    CONFIG.set_config(Path(root + '/../cobib/docs/debug.ini'))
+    # NOTE: normally you would never trigger an Add command before reading the database but in this
+    # controlled testing scenario we can be certain that this is fine
+    AddCommand().execute(['-b', './test/dummy_multi_file_entry.bib'])
+    read_database()
+    try:
+        test_tui(None, 'o', assert_open, {})
+    finally:
+        DeleteCommand().execute(['dummy_multi_file_entry'])
+
+
 def test_tui_resize(setup):
     """Test TUI resize handling."""
     # create pseudo-terminal
@@ -372,7 +460,6 @@ def test_tui_scrolling(keys, assertion, assertion_kwargs):
     root = os.path.abspath(os.path.dirname(__file__))
     CONFIG.set_config(Path(root + '/../cobib/docs/debug.ini'))
     # overwrite database file
-    CONFIG.config['DATABASE'] = {}
     CONFIG.config['DATABASE']['file'] = './test/scrolling_database.yaml'
     read_database()
     test_tui(None, keys, assertion, assertion_kwargs)
